@@ -2,35 +2,11 @@ seedHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
 
   ## Selecting the plots for one county
   db$PLOT <- plts[[x]]
-  ## Carrying out filter across all tables
-  #db <- clipFIA(db, mostRecent = FALSE)
-
-
-  ## Which grpByNames are in which table? Helps us subset below
-  grpP <- names(db$PLOT)[names(db$PLOT) %in% grpBy]
-  grpC <- names(db$COND)[names(db$COND) %in% grpBy & names(db$COND) %in% grpP == FALSE]
-  grpT <- names(db$SEEDLING)[names(db$SEEDLING) %in% grpBy & names(db$SEEDLING) %in% c(grpP, grpC) == FALSE]
 
   ### Only joining tables necessary to produce plot level estimates, adjusted for non-response
   data <- db$PLOT %>%
     left_join(db$COND, by = c('PLT_CN')) %>%
-    left_join(db$SEEDLING, by = c('PLT_CN', 'CONDID')) #%>%
-    ## Need a code that tells us where the tree was measured
-    ## macroplot, microplot, subplot
-    # mutate(PLOT_BASIS = case_when(
-    #   ## When DIA is na, adjustment is NA
-    #   is.na(DIA) ~ NA_character_,
-    #   ## When DIA is less than 5", use microplot value
-    #   DIA < 5 ~ 'MICR',
-    #   ## When DIA is greater than 5", use subplot value
-    #   DIA >= 5 & is.na(MACRO_BREAKPOINT_DIA) ~ 'SUBP',
-    #   DIA >= 5 & DIA < MACRO_BREAKPOINT_DIA ~ 'SUBP',
-    #   DIA >= MACRO_BREAKPOINT_DIA ~ 'MACR')) #%>%
-  #filter(!is.na(PLOT_BASIS))
-  # rename(YEAR = INVYR) %>%
-  # mutate_if(is.factor,
-  #           as.character) %>%
-  # filter(!is.na(YEAR))
+    left_join(db$SEEDLING, by = c('PLT_CN', 'CONDID'))
 
   ## Comprehensive indicator function
   data$aDI <- data$landD * data$aD_p * data$aD_c * data$sp
@@ -39,18 +15,25 @@ seedHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
 
 
   if (byPlot){
+
     grpBy <- c('YEAR', grpBy, 'PLOT_STATUS_CD')
+    grpSyms <- syms(grpBy)
+
     t <- data %>%
       mutate(YEAR = MEASYEAR) %>%
-      #distinct(PLT_CN, SUBP, TREE, .keep_all = TRUE) %>%
-      group_by(.dots = grpBy, PLT_CN) %>%
+      lazy_dt() %>%
+      group_by(!!!grpSyms, PLT_CN) %>%
       summarize(TPA = sum(TPA_UNADJ * tDI, na.rm = TRUE),
-                TPA_PERC = TPA / sum(TPA_UNADJ * pDI, na.rm = TRUE) * 100,
-                nStems = sum(TREECOUNT_CALC,na.rm = TRUE))
+                TPA_PERC = sum(TPA_UNADJ * pDI, na.rm = TRUE) * 100,
+                nStems = sum(TREECOUNT_CALC,na.rm = TRUE)) %>%
+      mutate(TPA_PERC = TPA / TPA_PERC) %>%
+      as.data.frame()
 
     a = NULL
 
   } else {
+    grpSyms <- syms(grpBy)
+
     ### Plot-level estimates
     a <- data %>%
       ## Will be lots of trees here, so CONDPROP listed multiple times
@@ -62,11 +45,12 @@ seedHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
 
     ## Tree plts
     t <- data %>%
-      #filter(!is.na(PLOT_BASIS)) %>%
-      group_by(PLT_CN, .dots = grpBy) %>%
+      lazy_dt() %>%
+      group_by(PLT_CN, !!!grpSyms) %>%
       summarize(tPlot = sum(TPA_UNADJ * tDI, na.rm = TRUE),
                 tTPlot = sum(TPA_UNADJ * pDI, na.rm = TRUE),
-                plotIn = ifelse(sum(tDI >  0, na.rm = TRUE), 1,0))
+                plotIn = ifelse(sum(tDI >  0, na.rm = TRUE), 1,0)) %>%
+      as.data.frame()
   }
 
 
@@ -86,45 +70,46 @@ seedHelper2 <- function(x, popState, a, t, grpBy, aGrpBy, method){
     grpBy <- c(grpBy, 'INVYR')
     aGrpBy <- c(aGrpBy, 'INVYR')
     popState[[x]]$P2POINTCNT <- popState[[x]]$P2POINTCNT_INVYR
+    popState[[x]]$P1POINTCNT <- popState[[x]]$P1POINTCNT_INVYR
     popState[[x]]$p2eu <- popState[[x]]$p2eu_INVYR
-
   }
 
+  aGrpSyms <- syms(aGrpBy)
+  grpSyms <- syms(grpBy)
+
   ## Strata level estimates
   aStrat <- a %>%
+    lazy_dt() %>%
     ## Rejoin with population tables
-    right_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
+    inner_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
     mutate(
       ## AREA
-      aAdj = case_when(
+      aAdj = dplyr::case_when(
         ## When NA, stay NA
         is.na(PROP_BASIS) ~ NA_real_,
         ## If the proportion was measured for a macroplot,
         ## use the macroplot value
         PROP_BASIS == 'MACR' ~ as.numeric(ADJ_FACTOR_MACR),
-        ## Otherwise, use the subpplot value
+        ## Otherwise, use the subplot value
         PROP_BASIS == 'SUBP' ~ ADJ_FACTOR_SUBP),
       fa = fa * aAdj) %>%
-    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, .dots = aGrpBy) %>%
-    summarize(a_t = length(unique(PLT_CN)) / first(P2POINTCNT),
-              aStrat = mean(fa * a_t, na.rm = TRUE),
+    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, !!!aGrpSyms) %>%
+    summarize(nh = dplyr::first(P2POINTCNT),
+              aStrat = sum(fa, na.rm = TRUE),
               plotIn_AREA = sum(plotIn, na.rm = TRUE),
-              n = n(),
-              ## We don't want a vector of these values, since they are repeated
-              nh = first(P2POINTCNT),
-              a = first(AREA_USED),
-              w = first(P1POINTCNT) / first(P1PNTCNT_EU),
-              p2eu = first(p2eu),
-              ndif = nh - n,
-              ## Strata level variances
-              av = ifelse(first(ESTN_METHOD == 'simple'),
-                          var(c(fa, numeric(ndif)) * first(a) / nh),
-                          (sum((c(fa, numeric(ndif))^2)) - nh * aStrat^2) / (nh * (nh-1))))
+              a = dplyr::first(AREA_USED),
+              w = dplyr::first(P1POINTCNT) / dplyr::first(P1PNTCNT_EU),
+              p2eu = dplyr::first(p2eu),
+              av = sum(fa^2, na.rm = TRUE)) %>%
+    mutate(aStrat = aStrat / nh,
+           av = (av - (nh * aStrat^2)) / (nh * (nh-1))) %>%
+    as.data.frame()
+
   ## Estimation unit
   aEst <- aStrat %>%
-    group_by(ESTN_UNIT_CN, .dots = aGrpBy) %>%
+    group_by(ESTN_UNIT_CN, !!!aGrpSyms) %>%
     summarize(aEst = unitMean(ESTN_METHOD, a, nh,  w, aStrat),
-              aVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, av, aStrat, aEst),
+              aVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, av, aStrat, aEst),
               plotIn_AREA = sum(plotIn_AREA, na.rm = TRUE))
 
   ######## ------------------ TREE ESTIMATES + CV
@@ -132,7 +117,7 @@ seedHelper2 <- function(x, popState, a, t, grpBy, aGrpBy, method){
   ## Strata level estimates
   tEst <- t %>%
     ## Rejoin with population tables
-    right_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
+    inner_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
     ## Need this for covariance later on
     left_join(select(a, fa, PLT_CN, PROP_BASIS, aGrpBy[aGrpBy %in% c('YEAR', 'INVYR') == FALSE]), by = c('PLT_CN', aGrpBy[aGrpBy %in% c('YEAR', 'INVYR') == FALSE])) %>%
     #Add adjustment factors
@@ -140,7 +125,7 @@ seedHelper2 <- function(x, popState, a, t, grpBy, aGrpBy, method){
       ## AREA
       tAdj = as.numeric(ADJ_FACTOR_MICR),
       ## AREA
-      aAdj = case_when(
+      aAdj = dplyr::case_when(
         ## When NA, stay NA
         is.na(PROP_BASIS) ~ NA_real_,
         ## If the proportion was measured for a macroplot,
@@ -151,59 +136,56 @@ seedHelper2 <- function(x, popState, a, t, grpBy, aGrpBy, method){
       fa = fa * aAdj,
       tPlot = tPlot * tAdj,
       tTPlot = tTPlot * tAdj) %>%
-    ## Extra step for variance issues
-    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN, .dots = grpBy) %>%
-    summarize(tPlot = sum(tPlot, na.rm = TRUE),
-              tTPlot = sum(tTPlot, na.rm = TRUE),
-              fa = first(fa),
-              plotIn = ifelse(sum(plotIn >  0, na.rm = TRUE), 1,0),
-              nh = first(P2POINTCNT),
-              p2eu = first(p2eu),
-              a = first(AREA_USED),
-              w = first(P1POINTCNT) / first(P1PNTCNT_EU)) %>%
+    # ## Extra step for variance issues
+    # group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN, .dots = grpBy) %>%
+    # summarize(tPlot = sum(tPlot, na.rm = TRUE),
+    #           tTPlot = sum(tTPlot, na.rm = TRUE),
+    #           fa = dplyr::first(fa),
+    #           plotIn = ifelse(sum(plotIn >  0, na.rm = TRUE), 1,0),
+    #           nh = dplyr::first(P2POINTCNT),
+    #           p2eu = dplyr::first(p2eu),
+    #           a = dplyr::first(AREA_USED),
+    #           w = dplyr::first(P1POINTCNT) / dplyr::first(P1PNTCNT_EU)) %>%
     ## Joining area data so we can compute ratio variances
     left_join(select(aStrat, aStrat, av, ESTN_UNIT_CN, STRATUM_CN, ESTN_METHOD, aGrpBy), by = c('ESTN_UNIT_CN', 'ESTN_METHOD', 'STRATUM_CN', aGrpBy)) %>%
     ## Strata level
-    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, .dots = grpBy) %>%
-    summarize(r_t = length(unique(PLT_CN)) / first(nh),
-              tStrat = mean(tPlot * r_t, na.rm = TRUE),
-              tTStrat = mean(tTPlot * r_t, na.rm = TRUE),
-              aStrat = first(aStrat),
+    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, !!!grpSyms) %>%
+    summarize(nh = dplyr::first(P2POINTCNT),
+              p2eu = dplyr::first(p2eu),
+              a = dplyr::first(AREA_USED),
+              w = dplyr::first(P1POINTCNT) / dplyr::first(P1PNTCNT_EU),
+              tStrat = sum(tPlot, na.rm = TRUE),
+              tTStrat = sum(tTPlot, na.rm = TRUE),
+              aStrat = dplyr::first(aStrat),
               plotIn_TREE = sum(plotIn, na.rm = TRUE),
-              n = n(),
-              ## We don't want a vector of these values, since they are repeated
-              nh = first(nh),
-              a = first(a),
-              w = first(w),
-              p2eu = first(p2eu),
-              ndif = nh - n,
+
               ## Strata level variances
-              #aVar = (sum(forArea^2) - sum(P2POINTCNT * aStrat^2)) / (P2POINTCNT * (P2POINTCNT-1)),
-              tv = ifelse(first(ESTN_METHOD == 'simple'),
-                          var(c(tPlot, numeric(ndif)) * first(a) / nh),
-                          (sum(c(tPlot, numeric(ndif))^2) - sum(nh * tStrat^2)) / (nh * (nh-1))), # Stratified and double cases
-              tTv = ifelse(first(ESTN_METHOD == 'simple'),
-                           var(c(tTPlot, numeric(ndif)) * first(a) / nh),
-                           (sum(c(tTPlot, numeric(ndif))^2) - sum(nh * tTStrat^2)) / (nh * (nh-1))), # Stratified and double cases
-              # Strata level covariances
-              cvStrat_t = ifelse(first(ESTN_METHOD == 'simple'),
-                                 cov(fa,tPlot),
-                                 (sum(fa*tPlot, na.rm = TRUE) - sum(nh * aStrat *tStrat)) / (nh * (nh-1))), # Stratified and double cases
-              cvStrat_tT = ifelse(first(ESTN_METHOD == 'simple'),
-                                  cov(tTPlot,tPlot),
-                                  (sum(tTPlot*tPlot, na.rm = TRUE) - sum(nh * tTStrat *tStrat)) / (nh * (nh-1)))) %>%
+              tv = sum(tPlot^2, na.rm = TRUE),
+              tTv = sum(tTPlot^2, na.rm = TRUE),
+
+              ## Strata level covariances
+              cvStrat_t = sum(fa*tPlot, na.rm = TRUE),
+              cvStrat_tT = sum(tPlot*tTPlot,na.rm = TRUE)) %>%
+    mutate(tStrat = tStrat / nh,
+           tTStrat = tTStrat / nh,
+           adj = nh * (nh-1),
+           tv = (tv - (nh*tStrat^2)) / adj,
+           tTv = (tTv - (nh*tTStrat^2)) / adj,
+           cvStrat_t = (cvStrat_t - (nh * tStrat * aStrat)) / adj,
+           cvStrat_tT = (cvStrat_tT - (nh * tStrat * tTStrat)) / adj) %>%
+    as.data.frame() %>%
     ## Estimation unit
     left_join(select(aEst, ESTN_UNIT_CN, aEst, aVar, aGrpBy), by = c('ESTN_UNIT_CN', aGrpBy)) %>%
     group_by(ESTN_UNIT_CN, .dots = grpBy) %>%
     summarize(tEst = unitMean(ESTN_METHOD, a, nh,  w, tStrat),
               tTEst = unitMean(ESTN_METHOD, a, nh,  w, tTStrat),
               plotIn_TREE = sum(plotIn_TREE, na.rm = TRUE),
-              N = first(p2eu),
-              tVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, tv, tStrat, tEst),
-              tTVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, tTv, tTStrat, tTEst),
+              N = dplyr::first(p2eu),
+              tVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, tv, tStrat, tEst),
+              tTVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, tTv, tTStrat, tTEst),
               # Unit Covariance
-              cvEst_t = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_t, tStrat, tEst, aStrat, aEst),
-              cvEst_tT = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_t, tStrat, tEst, tTStrat, tTEst))
+              cvEst_t = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_t, tStrat, tEst, aStrat, aEst),
+              cvEst_tT = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_t, tStrat, tEst, tTStrat, tTEst))
 
   out <- list(tEst = tEst, aEst = aEst)
 
@@ -275,10 +257,10 @@ seedHelper <- function(x, combos, data, grpBy, aGrpBy, totals, SE){
       summarize(tPlot = sum(TPA_UNADJ * tAdj * tDI, na.rm = TRUE),
                 tTPlot = sum(TPA_UNADJ * tAdj * pDI, na.rm = TRUE),
                 plotIn = ifelse(sum(tDI >  0, na.rm = TRUE), 1,0),
-                a = first(AREA_USED),
-                p1EU = first(P1PNTCNT_EU),
-                p1 = first(P1POINTCNT),
-                p2 = first(P2POINTCNT))
+                a = dplyr::first(AREA_USED),
+                p1EU = dplyr::first(P1PNTCNT_EU),
+                p1 = dplyr::first(P1POINTCNT),
+                p2 = dplyr::first(P2POINTCNT))
     ### Compute total AREA in the domain of interest
     aInt <- data %>%
       #filter(EVALID %in% aID) %>%
@@ -286,10 +268,10 @@ seedHelper <- function(x, combos, data, grpBy, aGrpBy, totals, SE){
       group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN) %>%
       summarize(fa = sum(CONDPROP_UNADJ * aDI * aAdj, na.rm = TRUE),
                 plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0),
-                a = first(AREA_USED),
-                p1EU = first(P1PNTCNT_EU),
-                p1 = first(P1POINTCNT),
-                p2 = first(P2POINTCNT))
+                a = dplyr::first(AREA_USED),
+                p1EU = dplyr::first(P1PNTCNT_EU),
+                p1 = dplyr::first(P1POINTCNT),
+                p2 = dplyr::first(P2POINTCNT))
 
     # Continue through totals
     t <- tInt %>%
@@ -300,18 +282,18 @@ seedHelper <- function(x, combos, data, grpBy, aGrpBy, totals, SE){
                 tTStrat = mean(tTPlot, na.rm = TRUE),
                 plotIn_SEEDLING = sum(plotIn_t, na.rm = TRUE),
                 plotIn_AREA = sum(plotIn_a, na.rm = TRUE),
-                a = first(a_t),
-                w = first(p1_t) / first(p1EU_a), # Stratum weight
-                nh = first(p2_t), # Number plots in stratum
+                a = dplyr::first(a_t),
+                w = dplyr::first(p1_t) / dplyr::first(p1EU_a), # Stratum weight
+                nh = dplyr::first(p2_t), # Number plots in stratum
                 # Strata level variances
                 tv = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(tPlot * first(a) / nh),
+                            var(tPlot * dplyr::first(a) / nh),
                             (sum(tPlot^2) - sum(nh * tStrat^2)) / (nh * (nh-1))), # Stratified and double cases
                 tTv = ifelse(first(ESTN_METHOD == 'simple'),
-                             var(tTPlot * first(a) / nh),
+                             var(tTPlot * dplyr::first(a) / nh),
                              (sum(tTPlot^2) - sum(nh * tTStrat^2)) / (nh * (nh-1))), # Stratified and double cases
                 av = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(fa * first(a) / nh),
+                            var(fa * dplyr::first(a) / nh),
                             (sum(fa^2) - sum(nh * aStrat^2)) / (nh * (nh-1))),
                 # Strata level covariances
                 cvStrat_t = ifelse(first(ESTN_METHOD == 'simple'),
@@ -471,10 +453,10 @@ tpaNewHelper <- function(x, combos, data, totals, SE){
     #             tTPlot = sum(TPA_UNADJ * tAdj * pDI, na.rm = TRUE),
     #             bTPlot = sum(basalArea(DIA) * TPA_UNADJ * tAdj * pDI, na.rm = TRUE),
     #             plotIn = ifelse(sum(tDI >  0, na.rm = TRUE), 1,0),
-    #             a = first(AREA_USED),
-    #             p1EU = first(P1PNTCNT_EU),
-    #             p1 = first(P1POINTCNT),
-    #             p2 = first(P2POINTCNT))
+    #             a = dplyr::first(AREA_USED),
+    #             p1EU = dplyr::first(P1PNTCNT_EU),
+    #             p1 = dplyr::first(P1POINTCNT),
+    #             p2 = dplyr::first(P2POINTCNT))
     # ### Compute total AREA in the domain of interest
     # aInt <- data %>%
     #   #filter(EVALID %in% aID) %>%
@@ -482,10 +464,10 @@ tpaNewHelper <- function(x, combos, data, totals, SE){
     #   group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN) %>%
     #   summarize(fa = sum(CONDPROP_UNADJ * aDI * aAdj, na.rm = TRUE),
     #             plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0),
-    #             a = first(AREA_USED),
-    #             p1EU = first(P1PNTCNT_EU),
-    #             p1 = first(P1POINTCNT),
-    #             p2 = first(P2POINTCNT))
+    #             a = dplyr::first(AREA_USED),
+    #             p1EU = dplyr::first(P1PNTCNT_EU),
+    #             p1 = dplyr::first(P1POINTCNT),
+    #             p2 = dplyr::first(P2POINTCNT))
     #
     # # Continue through totals
     # t <- tInt %>%
@@ -509,24 +491,24 @@ tpaNewHelper <- function(x, combos, data, totals, SE){
                 bTStrat = mean(bTPlot, na.rm = TRUE)* nPlots/first(totalPlots),
                 plotIn_SEEDLING = sum(plotIn_t, na.rm = TRUE),
                 plotIn_AREA = sum(plotIn_a, na.rm = TRUE),
-                a = first(a),
-                w = first(p1) / first(p1_eu), # Stratum weight
-                nh = first(p2), # Number plots in stratum
+                a = dplyr::first(a),
+                w = dplyr::first(p1) / dplyr::first(p1_eu), # Stratum weight
+                nh = dplyr::first(p2), # Number plots in stratum
                 # Strata level variances
                 tv = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(tPlot * first(a) / nh),
+                            var(tPlot * dplyr::first(a) / nh),
                             (sum(tPlot^2) - sum(nh * tStrat^2)) / (nh * (nh-1))), # Stratified and double cases
                 bv = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(bPlot * first(a) / nh),
+                            var(bPlot * dplyr::first(a) / nh),
                             (sum(bPlot^2) - sum(nh * bStrat^2)) / (nh * (nh-1))),
                 tTv = ifelse(first(ESTN_METHOD == 'simple'),
-                             var(tTPlot * first(a) / nh),
+                             var(tTPlot * dplyr::first(a) / nh),
                              (sum(tTPlot^2) - sum(nh * tTStrat^2)) / (nh * (nh-1))), # Stratified and double cases
                 bTv = ifelse(first(ESTN_METHOD == 'simple'),
-                             var(bTPlot * first(a) / nh),
+                             var(bTPlot * dplyr::first(a) / nh),
                              (sum(bTPlot^2) - sum(nh * bTStrat^2)) / (nh * (nh-1))),
                 av = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(fa * first(a) / nh),
+                            var(fa * dplyr::first(a) / nh),
                             (sum(fa^2) - sum(nh * aStrat^2)) / (nh * (nh-1))),
                 # Strata level covariances
                 cvStrat_t = ifelse(first(ESTN_METHOD == 'simple'),
