@@ -2,51 +2,51 @@ ssHelper1 <- function(x, plts, db, grpBy, byPlot){
 
   ## Selecting the plots for one county
   db$PLOT <- plts[[x]]
-  ## Carrying out filter across all tables
-  #db <- clipFIA(db, mostRecent = FALSE)
-
-  ## Which grpByNames are in which table? Helps us subset below
-  grpP <- names(db$PLOT)[names(db$PLOT) %in% grpBy]
-  grpC <- names(db$COND)[names(db$COND) %in% grpBy & names(db$COND) %in% grpP == FALSE]
 
   ### Only joining tables necessary to produce plot level estimates, adjusted for non-response
   data <- db$PLOT %>%
     left_join(db$COND, by = c('PLT_CN')) %>%
-    left_join(db$TREE, by = c('PLT_CN', 'CONDID')) #%>%
-    #filter(DIA >= 5)
+    left_join(db$TREE, by = c('PLT_CN', 'CONDID'))
 
-   ## Comprehensive indicator function
-   data$aDI <- data$landD * data$aD_p * data$aD_c * data$sp
-   data$tDI <- data$landD * data$aD_p * data$aD_c * data$sp
+  ## Comprehensive indicator function
+  data$aDI <- data$landD * data$aD_p * data$aD_c * data$sp
 
 
 
   if (byPlot){
+
     grpBy <- c('YEAR', grpBy, 'PLOT_STATUS_CD')
+    grpSyms <- syms(grpBy)
+
     t <- data %>%
       mutate(YEAR = INVYR) %>%
       distinct(PLT_CN, SUBP, TREE, .keep_all = TRUE) %>%
-      group_by(.dots = grpBy, PLT_CN) %>%
+      lazy_dt() %>%
+      group_by(!!!grpSyms, PLT_CN) %>%
       summarize(stage = structHelper(DIA, CCLCD),
                 nStems = length(which(tDI == 1))) %>%
+      as.data.frame() %>%
       ungroup() %>%
       mutate_if(is.factor, as.character)
 
   } else {
+    grpSyms <- syms(grpBy)
     # Compute estimates
     t <- data %>%
       distinct(PLT_CN, SUBP, CONDID, TREE, .keep_all = TRUE) %>%
-      group_by(.dots = grpBy, PLT_CN, PROP_BASIS, CONDID) %>%
-      summarize(CONDPROP_UNADJ = first(CONDPROP_UNADJ), # Area
+      lazy_dt() %>%
+      group_by(!!!grpSyms, PLT_CN, PROP_BASIS, CONDID) %>%
+      summarize(CONDPROP_UNADJ = dplyr::first(CONDPROP_UNADJ), # Area
                 stage = structHelper(DIA, CCLCD),
-                aDI = first(aDI)) %>%
-      group_by(.dots = grpBy, PLT_CN, PROP_BASIS) %>%
+                aDI = dplyr::first(aDI)) %>%
+      group_by(!!!grpSyms, PLT_CN, PROP_BASIS) %>%
       summarize(p = sum(CONDPROP_UNADJ[stage == 'pole'] * aDI[stage == 'pole'], na.rm = TRUE),
                 ma = sum(CONDPROP_UNADJ[stage == 'mature'] * aDI[stage == 'mature'], na.rm = TRUE),
                 l = sum(CONDPROP_UNADJ[stage == 'late'] * aDI[stage == 'late'], na.rm = TRUE),
                 mo = sum(CONDPROP_UNADJ[stage == 'mosaic'] * aDI[stage == 'mosaic'], na.rm = TRUE),
                 fa = sum(CONDPROP_UNADJ * aDI, na.rm = TRUE),
-                plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0))
+                plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0)) %>%
+      as.data.frame()
   }
 
   pltOut <- list(t = t)
@@ -63,17 +63,19 @@ ssHelper2 <- function(x, popState, t, grpBy, method){
     grpBy <- c(grpBy, 'INVYR')
     #aGrpBy <- c(aGrpBy, 'INVYR')
     popState[[x]]$P2POINTCNT <- popState[[x]]$P2POINTCNT_INVYR
+    popState[[x]]$P1POINTCNT <- popState[[x]]$P1POINTCNT_INVYR
     popState[[x]]$p2eu <- popState[[x]]$p2eu_INVYR
-
   }
 
+  grpSyms <- syms(grpBy)
+
   ## Strata level estimates
   tEst <- t %>%
     ## Rejoin with population tables
-    right_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
+    inner_join(select(popState[[x]], -c(STATECD)), by = 'PLT_CN') %>%
     mutate(
       ## AREA
-      aAdj = case_when(
+      aAdj = dplyr::case_when(
         ## When NA, stay NA
         is.na(PROP_BASIS) ~ NA_real_,
         ## If the proportion was measured for a macroplot,
@@ -86,32 +88,45 @@ ssHelper2 <- function(x, popState, t, grpBy, method){
       ma = ma * aAdj,
       l = l * aAdj,
       mo = mo * aAdj) %>%
-    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, .dots = grpBy) %>%
-    summarize(a_t = length(unique(PLT_CN)) / first(P2POINTCNT),
-              aStrat = mean(fa * a_t, na.rm = TRUE),
-              pStrat = mean(p * a_t, na.rm = TRUE),
-              maStrat = mean(ma * a_t, na.rm = TRUE),
-              lStrat = mean(l * a_t, na.rm = TRUE),
-              moStrat = mean(mo * a_t, na.rm = TRUE),
+    group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, !!!grpSyms) %>%
+    summarize(nh = dplyr::first(P2POINTCNT),
+              a = dplyr::first(AREA_USED),
+              w = dplyr::first(P1POINTCNT) / dplyr::first(P1PNTCNT_EU),
+              p2eu = dplyr::first(p2eu),
+              aStrat = sum(fa, na.rm = TRUE),
+              pStrat = sum(p, na.rm = TRUE),
+              maStrat = sum(ma, na.rm = TRUE),
+              lStrat = sum(l, na.rm = TRUE),
+              moStrat = sum(mo, na.rm = TRUE),
               plotIn_AREA = sum(plotIn, na.rm = TRUE),
-              n = n(),
-              ## We don't want a vector of these values, since they are repeated
-              nh = first(P2POINTCNT),
-              a = first(AREA_USED),
-              w = first(P1POINTCNT) / first(P1PNTCNT_EU),
-              p2eu = first(p2eu),
-              ndif = nh - n,
+
               # ## Strata level variances
-              av = stratVar(ESTN_METHOD, fa, aStrat, ndif, a, nh),
-              pv = stratVar(ESTN_METHOD, p, pStrat, ndif, a, nh),
-              mav = stratVar(ESTN_METHOD, ma, maStrat, ndif, a, nh),
-              lv = stratVar(ESTN_METHOD, l, lStrat, ndif, a, nh),
-              mov = stratVar(ESTN_METHOD, mo, moStrat, ndif, a, nh),
+              av = sum(fa^2, na.rm = TRUE),
+              pv = sum(p^2, na.rm = TRUE),
+              mav = sum(ma^2, na.rm = TRUE),
+              lv = sum(l^2, na.rm = TRUE),
+              mov = sum(mo^2, na.rm = TRUE),
               # Strata level covariances
-              cvStrat_p = stratVar(ESTN_METHOD, p, pStrat, ndif, a, nh, fa, aStrat),
-              cvStrat_ma = stratVar(ESTN_METHOD, ma, maStrat, ndif, a, nh, fa, aStrat),
-              cvStrat_l = stratVar(ESTN_METHOD, l, lStrat, ndif, a, nh, fa, aStrat),
-              cvStrat_mo = stratVar(ESTN_METHOD, mo, moStrat, ndif, a, nh, fa, aStrat)) %>%
+              cvStrat_p = sum(p*fa, na.rm = TRUE),
+              cvStrat_ma = sum(ma*fa, na.rm = TRUE),
+              cvStrat_l = sum(l*fa, na.rm = TRUE),
+              cvStrat_mo = sum(mo*fa, na.rm = TRUE)) %>%
+    mutate(aStrat = aStrat / nh,
+           pStrat = pStrat / nh,
+           maStrat = maStrat / nh,
+           lStrat = lStrat / nh,
+           moStrat = moStrat / nh,
+           adj = nh * (nh-1),
+           av = (av - (nh*aStrat^2)) / adj,
+           pv = (pv - (nh*pStrat^2)) / adj,
+           mav = (mav - (nh*maStrat^2)) / adj,
+           lv = (lv - (nh*lStrat^2)) / adj,
+           mov = (mov - (nh*moStrat^2)) / adj,
+           cvStrat_p = (cvStrat_p - (nh * pStrat * aStrat)) / adj,
+           cvStrat_ma = (cvStrat_ma - (nh * maStrat * aStrat)) / adj,
+           cvStrat_l = (cvStrat_l - (nh * lStrat * aStrat)) / adj,
+           cvStrat_mo = (cvStrat_mo - (nh * moStrat * aStrat)) / adj) %>%
+    as.data.frame() %>%
     ## Estimation unit
     group_by(ESTN_UNIT_CN, .dots = grpBy) %>%
     summarize(aEst = unitMean(ESTN_METHOD, a, nh,  w, aStrat),
@@ -119,16 +134,16 @@ ssHelper2 <- function(x, popState, t, grpBy, method){
               maEst = unitMean(ESTN_METHOD, a, nh,  w, maStrat),
               lEst = unitMean(ESTN_METHOD, a, nh,  w, lStrat),
               moEst = unitMean(ESTN_METHOD, a, nh,  w, moStrat),
-              N = first(p2eu),
-              aVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, av, aStrat, aEst),
-              pVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, pv, pStrat, pEst),
-              maVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, mav, maStrat, maEst),
-              lVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, lv, lStrat, lEst),
-              moVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, first(p2eu), w, mov, moStrat, moEst),
-              cvEst_p = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_p, pStrat, pEst, aStrat, aEst),
-              cvEst_ma = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_ma, maStrat, maEst, aStrat, aEst),
-              cvEst_l = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_l, lStrat, lEst, aStrat, aEst),
-              cvEst_mo = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, first(p2eu), w, cvStrat_mo, moStrat, moEst, aStrat, aEst),
+              N = dplyr::first(p2eu),
+              aVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, av, aStrat, aEst),
+              pVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, pv, pStrat, pEst),
+              maVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, mav, maStrat, maEst),
+              lVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, lv, lStrat, lEst),
+              moVar = unitVarNew(method = 'var', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, mov, moStrat, moEst),
+              cvEst_p = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_p, pStrat, pEst, aStrat, aEst),
+              cvEst_ma = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_ma, maStrat, maEst, aStrat, aEst),
+              cvEst_l = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_l, lStrat, lEst, aStrat, aEst),
+              cvEst_mo = unitVarNew(method = 'cov', ESTN_METHOD, a, nh, dplyr::first(p2eu), w, cvStrat_mo, moStrat, moEst, aStrat, aEst),
               plotIn_AREA = sum(plotIn_AREA, na.rm = TRUE))
 
   out <- list(tEst = tEst)
@@ -180,14 +195,14 @@ standStructHelper <- function(x, combos, data, grpBy, totals, tidy, SE){
     s <- data %>%
       group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN, CONDID) %>%
       # filter(tDI > 0) %>%
-      summarize(CONDPROP_UNADJ = first(CONDPROP_UNADJ),
+      summarize(CONDPROP_UNADJ = dplyr::first(CONDPROP_UNADJ),
                 stage = structHelper(DIA, CCLCD),
-                a = first(AREA_USED),
-                p1EU = first(P1PNTCNT_EU),
-                p1 = first(P1POINTCNT),
-                p2 = first(P2POINTCNT),
-                aAdj = first(aAdj),
-                aDI = first(aDI)) %>%
+                a = dplyr::first(AREA_USED),
+                p1EU = dplyr::first(P1PNTCNT_EU),
+                p1 = dplyr::first(P1POINTCNT),
+                p2 = dplyr::first(P2POINTCNT),
+                aAdj = dplyr::first(aAdj),
+                aDI = dplyr::first(aDI)) %>%
       group_by(ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN) %>%
       summarize(p = sum(CONDPROP_UNADJ[stage == 'pole'] * aDI[stage == 'pole'] * aAdj[stage == 'pole'], na.rm = TRUE),
                 ma = sum(CONDPROP_UNADJ[stage == 'mature'] * aDI[stage == 'mature'] * aAdj[stage == 'mature'], na.rm = TRUE),
@@ -195,10 +210,10 @@ standStructHelper <- function(x, combos, data, grpBy, totals, tidy, SE){
                 mo = sum(CONDPROP_UNADJ[stage == 'mosaic'] * aDI[stage == 'mosaic'] * aAdj[stage == 'mosaic'], na.rm = TRUE),
                 faFull = sum(CONDPROP_UNADJ * aDI * aAdj, na.rm = TRUE),
                 plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0),
-                p1EU = first(p1EU),
-                a = first(a),
-                p1 = first(p1),
-                p2 = first(p2)) %>%
+                p1EU = dplyr::first(p1EU),
+                a = dplyr::first(a),
+                p1 = dplyr::first(p1),
+                p2 = dplyr::first(p2)) %>%
       # Continue through totals
       #d <- dInt %>%
       #filter(plotIn > 0) %>%
@@ -210,24 +225,24 @@ standStructHelper <- function(x, combos, data, grpBy, totals, tidy, SE){
                 fullStrat = mean(faFull, na.rm = TRUE),
                 plotIn = sum(plotIn, na.rm = TRUE),
                 #vPlots = ifelse(plotIn > 1, plotIn, NA),
-                a = first(a),
-                w = first(p1) / first(p1EU), # Stratum weight
-                nh = first(p2), # Number plots in stratum
+                a = dplyr::first(a),
+                w = dplyr::first(p1) / dplyr::first(p1EU), # Stratum weight
+                nh = dplyr::first(p2), # Number plots in stratum
                 # Strata level variances
                 pv = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(p * first(a) / nh),
+                            var(p * dplyr::first(a) / nh),
                             (sum(p^2, na.rm = TRUE) - sum(nh * pStrat^2, na.rm = TRUE)) / (nh * (nh-1))),
                 mav = ifelse(first(ESTN_METHOD == 'simple'),
-                             var(ma * first(a) / nh),
+                             var(ma * dplyr::first(a) / nh),
                              (sum(ma^2, na.rm = TRUE) - sum(nh * maStrat^2, na.rm = TRUE)) / (nh * (nh-1))),
                 lv = ifelse(first(ESTN_METHOD == 'simple'),
-                            var(l * first(a) / nh),
+                            var(l * dplyr::first(a) / nh),
                             (sum(l^2, na.rm = TRUE) - sum(nh * lStrat^2, na.rm = TRUE)) / (nh * (nh-1))),
                 mov = ifelse(first(ESTN_METHOD == 'simple'),
-                             var(mo * first(a) / nh),
+                             var(mo * dplyr::first(a) / nh),
                              (sum(mo^2, na.rm = TRUE) - sum(nh * moStrat^2, na.rm = TRUE)) / (nh * (nh-1))),
                 fullv = ifelse(first(ESTN_METHOD == 'simple'),
-                               var(faFull * first(a) / nh),
+                               var(faFull * dplyr::first(a) / nh),
                                (sum(faFull^2, na.rm = TRUE) - sum(nh * fullStrat^2, na.rm = TRUE)) / (nh * (nh-1))),
                 # cvStrat_t = ifelse(first(ESTN_METHOD == 'simple'),
                 #                    cov(fa,tPlot),
@@ -314,11 +329,11 @@ standStructHelper <- function(x, combos, data, grpBy, totals, tidy, SE){
     s <- data %>%
       group_by(.dots = grpBy, ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN, CONDID) %>%
       # filter(tDI > 0) %>%
-      summarize(CONDPROP_UNADJ = first(CONDPROP_UNADJ),
+      summarize(CONDPROP_UNADJ = dplyr::first(CONDPROP_UNADJ),
                 stage = structHelper(DIA, CCLCD),
-                aAdj = first(aAdj),
-                aDI = first(aDI),
-                EXPNS = first(EXPNS)) %>%
+                aAdj = dplyr::first(aAdj),
+                aDI = dplyr::first(aDI),
+                EXPNS = dplyr::first(EXPNS)) %>%
       group_by(.dots = grpBy, ESTN_UNIT_CN, ESTN_METHOD, STRATUM_CN, PLT_CN) %>%
       summarize(p = sum(CONDPROP_UNADJ[stage == 'pole'] * aDI[stage == 'pole'] * aAdj[stage == 'pole'] * EXPNS[stage == 'pole'], na.rm = TRUE),
                 ma = sum(CONDPROP_UNADJ[stage == 'mature'] * aDI[stage == 'mature'] * aAdj[stage == 'mature'] * EXPNS[stage == 'mature'], na.rm = TRUE),
